class LogFormatProxyModel : public QIdentityProxyModel
{
@@ -236,15 +237,30 @@ void LogPage::on_btnPaste_clicked()
return;
//FIXME: turn this into a proper task and move the upload logic out of GuiUtil!
- m_model->append(MessageLevel::MultiMC, QString("MultiMC: Log upload triggered at: %1").arg(QDateTime::currentDateTime().toString(Qt::RFC2822Date)));
+ m_model->append(
+ MessageLevel::Launcher,
+ QString("%2: Log upload triggered at: %1").arg(
+ QDateTime::currentDateTime().toString(Qt::RFC2822Date),
+ BuildConfig.LAUNCHER_NAME
+ )
+ );
auto url = GuiUtil::uploadPaste(m_model->toPlainText(), this);
if(!url.isEmpty())
{
- m_model->append(MessageLevel::MultiMC, QString("MultiMC: Log uploaded to: %1").arg(url));
+ m_model->append(
+ MessageLevel::Launcher,
+ QString("%2: Log uploaded to: %1").arg(
+ url,
+ BuildConfig.LAUNCHER_NAME
+ )
+ );
}
else
{
- m_model->append(MessageLevel::Error, "MultiMC: Log upload failed!");
+ m_model->append(
+ MessageLevel::Error,
+ QString("%1: Log upload failed!").arg(BuildConfig.LAUNCHER_NAME)
+ );
}
}
@@ -252,7 +268,7 @@ void LogPage::on_btnCopy_clicked()
{
if(!m_model)
return;
- m_model->append(MessageLevel::MultiMC, QString("Clipboard copy at: %1").arg(QDateTime::currentDateTime().toString(Qt::RFC2822Date)));
+ m_model->append(MessageLevel::Launcher, QString("Clipboard copy at: %1").arg(QDateTime::currentDateTime().toString(Qt::RFC2822Date)));
GuiUtil::setClipboardText(m_model->toPlainText());
}
diff --git a/launcher/resources/multimc/index.theme b/launcher/resources/multimc/index.theme
index 6061b7f8..070e23f1 100644
--- a/launcher/resources/multimc/index.theme
+++ b/launcher/resources/multimc/index.theme
@@ -1,6 +1,6 @@
[Icon Theme]
Name=multimc
-Comment=MultiMC Default Icons
+Comment=Default Icons
Inherits=default
Directories=8x8,16x16,22x22,24x24,32x32,32x32/instances,48x48,50x50/instances,64x64,128x128/instances,256x256,scalable,scalable/instances
diff --git a/launcher/setupwizard/AnalyticsWizardPage.cpp b/launcher/setupwizard/AnalyticsWizardPage.cpp
index 3ecc034c..f1d7b006 100644
--- a/launcher/setupwizard/AnalyticsWizardPage.cpp
+++ b/launcher/setupwizard/AnalyticsWizardPage.cpp
@@ -47,13 +47,13 @@ void AnalyticsWizardPage::retranslate()
setSubTitle(tr("We track some anonymous statistics about users."));
textBrowser->setHtml(tr(
""
- "MultiMC sends anonymous usage statistics on every start of the application. This helps us decide what platforms and issues to focus on.
"
+ "The launcher sends anonymous usage statistics on every start of the application. This helps us decide what platforms and issues to focus on.
"
"The data is processed by Google Analytics, see their article on the "
"matter.
"
"The following data is collected:
"
- "- A random unique ID of the MultiMC installation.
It is stored in the application settings (multimc.cfg). "
+ "- A random unique ID of the installation.
It is stored in the application settings file. "
"- Anonymized (partial) IP address.
"
- "- MultiMC version.
"
+ "- Launcher version.
"
"- Operating system name, version and architecture.
"
"- CPU architecture (kernel architecture on linux).
"
"- Size of system memory.
"
diff --git a/launcher/setupwizard/LanguageWizardPage.cpp b/launcher/setupwizard/LanguageWizardPage.cpp
index 6a5fd737..e352ccca 100644
--- a/launcher/setupwizard/LanguageWizardPage.cpp
+++ b/launcher/setupwizard/LanguageWizardPage.cpp
@@ -4,6 +4,7 @@
#include "widgets/LanguageSelectionWidget.h"
#include
+#include
LanguageWizardPage::LanguageWizardPage(QWidget *parent)
: BaseWizardPage(parent)
@@ -43,6 +44,6 @@ bool LanguageWizardPage::validatePage()
void LanguageWizardPage::retranslate()
{
setTitle(tr("Language"));
- setSubTitle(tr("Select the language to use in MultiMC"));
+ setSubTitle(tr("Select the language to use in %1").arg(BuildConfig.LAUNCHER_NAME));
mainWidget->retranslate();
}
diff --git a/launcher/setupwizard/SetupWizard.cpp b/launcher/setupwizard/SetupWizard.cpp
index 31334924..46b2ef79 100644
--- a/launcher/setupwizard/SetupWizard.cpp
+++ b/launcher/setupwizard/SetupWizard.cpp
@@ -10,6 +10,7 @@
#include
#include
+#include
SetupWizard::SetupWizard(QWidget *parent) : QWizard(parent)
{
@@ -30,7 +31,7 @@ void SetupWizard::retranslate()
setButtonText(QWizard::BackButton, tr("< &Back"));
setButtonText(QWizard::FinishButton, tr("&Finish"));
setButtonText(QWizard::CustomButton1, tr("&Refresh"));
- setWindowTitle(tr("MultiMC Quick Setup"));
+ setWindowTitle(tr("%1 Quick Setup").arg(BuildConfig.LAUNCHER_NAME));
}
BaseWizardPage * SetupWizard::getBasePage(int id)
diff --git a/launcher/tasks/Task.cpp b/launcher/tasks/Task.cpp
index d0ac7569..57307b43 100644
--- a/launcher/tasks/Task.cpp
+++ b/launcher/tasks/Task.cpp
@@ -63,7 +63,7 @@ void Task::start()
}
case State::Running:
{
- qWarning() << "MultiMC tried to start task" << describe() << "while it was already running!";
+ qWarning() << "The launcher tried to start task" << describe() << "while it was already running!";
return;
}
}
diff --git a/launcher/updater/DownloadTask_test.cpp b/launcher/updater/DownloadTask_test.cpp
index 8d5375e8..dc263c17 100644
--- a/launcher/updater/DownloadTask_test.cpp
+++ b/launcher/updater/DownloadTask_test.cpp
@@ -77,7 +77,7 @@ slots:
QTest::addColumn("ret");
QTest::newRow("one")
- << MULTIMC_GET_TEST_FILE("data/1.json")
+ << GET_TEST_FILE("data/1.json")
<< (VersionFileList()
<< VersionFileEntry{"fileOne",
493,
@@ -93,7 +93,7 @@ slots:
"f12df554b21e320be6471d7154130e70"})
<< QString() << true;
QTest::newRow("two")
- << MULTIMC_GET_TEST_FILE("data/2.json")
+ << GET_TEST_FILE("data/2.json")
<< (VersionFileList()
<< VersionFileEntry{"fileOne",
493,
diff --git a/launcher/updater/UpdateChecker.cpp b/launcher/updater/UpdateChecker.cpp
index eea73dcf..c96a6c9f 100644
--- a/launcher/updater/UpdateChecker.cpp
+++ b/launcher/updater/UpdateChecker.cpp
@@ -190,14 +190,6 @@ void UpdateChecker::updateChanList(bool notifyNoUpdate)
return;
}
- if (m_channelUrl.isEmpty())
- {
- qCritical() << "Failed to update channel list. No channel list URL set."
- << "If you'd like to use MultiMC's update system, please pass the channel "
- "list URL to CMake at compile time.";
- return;
- }
-
m_chanListLoading = true;
NetJob *job = new NetJob("Update System Channel List");
job->addNetAction(Net::Download::makeByteArray(QUrl(m_channelUrl), &chanlistData));
diff --git a/launcher/widgets/CustomCommands.ui b/launcher/widgets/CustomCommands.ui
index 25b2681b..21964ad2 100644
--- a/launcher/widgets/CustomCommands.ui
+++ b/launcher/widgets/CustomCommands.ui
@@ -74,7 +74,7 @@
-
- <html><head/><body><p>Pre-launch command runs before the instance launches and post-exit command runs after it exits.</p><p>Both will be run in MultiMC's working folder with extra environment variables:</p><ul><li>$INST_NAME - Name of the instance</li><li>$INST_ID - ID of the instance (its folder name)</li><li>$INST_DIR - absolute path of the instance</li><li>$INST_MC_DIR - absolute path of minecraft</li><li>$INST_JAVA - java binary used for launch</li><li>$INST_JAVA_ARGS - command-line parameters used for launch</li></ul><p>Wrapper command allows launching using an extra wrapper program (like 'optirun' on Linux)</p></body></html>
+ <html><head/><body><p>Pre-launch command runs before the instance launches and post-exit command runs after it exits.</p><p>Both will be run in the launcher's working folder with extra environment variables:</p><ul><li>$INST_NAME - Name of the instance</li><li>$INST_ID - ID of the instance (its folder name)</li><li>$INST_DIR - absolute path of the instance</li><li>$INST_MC_DIR - absolute path of minecraft</li><li>$INST_JAVA - java binary used for launch</li><li>$INST_JAVA_ARGS - command-line parameters used for launch</li></ul><p>Wrapper command allows launching using an extra wrapper program (like 'optirun' on Linux)</p></body></html>
Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop
diff --git a/launcher/widgets/JavaSettingsWidget.cpp b/launcher/widgets/JavaSettingsWidget.cpp
index 672d6115..0e292bb8 100644
--- a/launcher/widgets/JavaSettingsWidget.cpp
+++ b/launcher/widgets/JavaSettingsWidget.cpp
@@ -16,6 +16,7 @@
#include
#include
#include
+#include
JavaSettingsWidget::JavaSettingsWidget(QWidget* parent) : QWidget(parent)
{
@@ -146,11 +147,11 @@ JavaSettingsWidget::ValidationStatus JavaSettingsWidget::validate()
this,
tr("No Java version selected"),
tr("You didn't select a Java version or selected something that doesn't work.\n"
- "MultiMC will not be able to start Minecraft.\n"
+ "%1 will not be able to start Minecraft.\n"
"Do you wish to proceed without any Java?"
"\n\n"
"You can change the Java version in the settings later.\n"
- ),
+ ).arg(BuildConfig.LAUNCHER_NAME),
QMessageBox::Warning,
QMessageBox::Yes | QMessageBox::No,
QMessageBox::NoButton
diff --git a/libraries/launcher/org/multimc/EntryPoint.java b/libraries/launcher/org/multimc/EntryPoint.java
index d47a9b18..0f904f5f 100644
--- a/libraries/launcher/org/multimc/EntryPoint.java
+++ b/libraries/launcher/org/multimc/EntryPoint.java
@@ -135,7 +135,7 @@ public class EntryPoint
}
if(isAborted)
{
- System.err.println("Launch aborted by MultiMC.");
+ System.err.println("Launch aborted by the launcher.");
return 1;
}
if(m_launcher != null)
diff --git a/notsecrets/CMakeLists.txt b/notsecrets/CMakeLists.txt
index 63930672..f12b5274 100644
--- a/notsecrets/CMakeLists.txt
+++ b/notsecrets/CMakeLists.txt
@@ -3,8 +3,15 @@ target_link_libraries(secrets Qt5::Core)
target_compile_definitions(secrets PUBLIC -DEMBED_SECRETS)
target_include_directories(secrets PUBLIC .)
-set(Launcher_Name "Launcher" PARENT_SCOPE)
+set(Launcher_CommonName "DevLauncher")
+
set(Launcher_Copyright "MultiMC Contributors" PARENT_SCOPE)
+set(Launcher_Domain "multimc.org" PARENT_SCOPE)
+set(Launcher_Name "${Launcher_CommonName}" PARENT_SCOPE)
+set(Launcher_DisplayName "${Launcher_CommonName} 5" PARENT_SCOPE)
+set(Launcher_UserAgent "${Launcher_CommonName}/5.0" PARENT_SCOPE)
+set(Launcher_ConfigFile "devlauncher.cfg" PARENT_SCOPE)
set(Launcher_Branding_ICNS "notsecrets/Launcher.icns" PARENT_SCOPE)
set(Launcher_Branding_WindowsRC "notsecrets/launcher.rc" PARENT_SCOPE)
+set(Launcher_Branding_LogoQRC "notsecrets/logo.qrc" PARENT_SCOPE)
diff --git a/notsecrets/logo.qrc b/notsecrets/logo.qrc
new file mode 100644
index 00000000..f1da6fe6
--- /dev/null
+++ b/notsecrets/logo.qrc
@@ -0,0 +1,8 @@
+
+
+
+ logo.svg
+
+
+
+
diff --git a/libraries/launcher/org/multimc/Utils.java b/libraries/launcher/org/multimc/Utils.java
index fcf3edce..353af7d3 100644
--- a/libraries/launcher/org/multimc/Utils.java
+++ b/libraries/launcher/org/multimc/Utils.java
@@ -94,7 +94,7 @@ public class Utils
}
/**
* Log to the MultiMC console
*
* @param message A String containing the message
* @param level A String containing the level name. See MinecraftLauncher::getLevel()
@@ -108,7 +108,7 @@ public class Utils
public static void log(String message)
{
- log(message, "MultiMC");
+ log(message, "Launcher");
}
public static void log()
@@ -94,7 +94,7 @@ public class Utils
}
/**
- * Log to the MultiMC console
+ * Log to the launcher console
*
* @param message A String containing the message